==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/CSISnapshotControllerBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSISnapshotControllerBuilder extends io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluentImpl<io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.CSISnapshotController,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerBuilder>{
  public CSISnapshotControllerBuilder() {
    this(false);
  }
  public CSISnapshotControllerBuilder(java.lang.Boolean validationEnabled) {
    this(new CSISnapshotController(), validationEnabled);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent) {
    this(fluent, false);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSISnapshotController(), validationEnabled);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance) {
    this(fluent, instance, false);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance) {
    this(instance,false);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.CSISnapshotController build() {
    CSISnapshotController buildable = new CSISnapshotController(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSISnapshotControllerBuilder that = (CSISnapshotControllerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/CSISnapshotControllerBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSISnapshotControllerBuilder extends io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluentImpl<io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.CSISnapshotController,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerBuilder>{
  public CSISnapshotControllerBuilder() {
    this(false);
  }
  public CSISnapshotControllerBuilder(java.lang.Boolean validationEnabled) {
    this(new CSISnapshotController(), validationEnabled);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent) {
    this(fluent, false);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSISnapshotController(), validationEnabled);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance) {
    this(fluent, instance, false);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance) {
    this(instance,false);
  }
  public CSISnapshotControllerBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotController instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.CSISnapshotController build() {
    CSISnapshotController buildable = new CSISnapshotController(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSISnapshotControllerBuilder that = (CSISnapshotControllerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
